@@ -18,7 +18,7 @@
 #Written using Boa-Constructor.
 #http://boa-constructor.sourceforge.net/
 #
-#Version 2.0.12 07/07/08
+#Version 2.0.16 23/10/08
 
 import wx
 from wx.lib.anchors import LayoutAnchors
@@ -293,7 +293,7 @@ class TunapieFrame(wx.Frame):
         self.TunapieStatus.SetFieldsCount(1)
         self._init_coll_TunapieStatus_Fields(self.TunapieStatus)
         self.SetStatusBar(self.TunapieStatus)
-
+        
         if commands.getoutput("uname")=='Darwin':
             mainsize=380
         else:
@@ -399,6 +399,7 @@ class TunapieFrame(wx.Frame):
                          # get error on first startup due to OnGenreBoxListItemSelected 
                          # being called before files exist.
         self.downloading=0 #set when downloading from server
+        self.startup=1
         self.downloadedshoutcast=0
         self.lastmod=-1 # tv or radio last modality when browsing favs?    
         self.reverse=0
@@ -496,9 +497,10 @@ class TunapieFrame(wx.Frame):
         self.setfontsize()
         if missing_players:
             missing_players.append("Please edit preferences manually.")
-            self.OnTunapieToolBarInfoTool(1,missing_players)
+            #self.OnTunapieToolBarInfoTool(1,missing_players)
+            print missing_players
         socket.setdefaulttimeout(20)
-        wx.CallAfter(self.download,)
+        wx.CallAfter(self.download)
         
     def setfontsize(self):
         size=int(self.newsize)
@@ -515,6 +517,7 @@ class TunapieFrame(wx.Frame):
         #only calls reload (which does the real downloading)
         #if has not already been done this session
         #self.radioselected=1
+        self.startup=0
         if int(self.shoutice):
             if not(self.downloadedshoutcast):
                 self.downloadedshoutcast=1
@@ -567,7 +570,7 @@ class TunapieFrame(wx.Frame):
                 self.downloading=2
                 return
         if(type==5): #icecast
-            try: icfile=urllib.urlretrieve('http://dir.xiph.org/?start=0&num=150000',self.home+'/.tunapie/icecast',self.reporthook)
+            try: icfile=urllib.urlretrieve('http://dir.xiph.org/yp.xml',self.home+'/.tunapie/icecast',self.reporthook)
             except IOError:
                 self.downloading=2
                 return
@@ -576,11 +579,6 @@ class TunapieFrame(wx.Frame):
                 return
         self.downloading=3
         #self.addtolistctrl(self.MainListCtrl, self.name,self.genre,self.bitrate,self.listeners,self.playing)
-        self.parsefiles()
-        self.updatefavs()
-        self.updatemain()
-        self.MainListCtrl.Select(0)
-        self.MainListCtrl.SetFocus()
         self.reloading=0
         return
     
@@ -992,12 +990,18 @@ class TunapieFrame(wx.Frame):
             time.sleep(0.2)
             wx.Yield()
             if (self.downloading==3):
+                self.SetStatusText('')
                 self.downloading=0
                 while 1:
                     time.sleep(0.2)
                     wx.Yield()
                     if (self.reloading==0):
                         self.SetStatusText('')
+                        self.parsefiles()
+                        self.updatefavs()
+                        self.updatemain()
+                        self.MainListCtrl.Select(0)
+                        self.MainListCtrl.SetFocus()
                         return
 
     def OnMainListCtrlListColClick(self, event):
@@ -1097,7 +1101,7 @@ class TunapieFrame(wx.Frame):
                 self.lastmod=1
                 try:
                     self.running=1
-                    tuner.playselection(self.mediaplayer,self.favurl[selection])
+                    tuner.playselection(self.mediaplayer,self.favurl[selection],0)
                 except IOError:
                     self.contacterror()
             return
@@ -1118,7 +1122,7 @@ class TunapieFrame(wx.Frame):
         if(self.radioselected):
             try: 
                 self.running=1
-                tuner.playselection(self.mediaplayer,self.url[selection])
+                tuner.playselection(self.mediaplayer,self.url[selection],0)
             except IOError: #if try to play empty stream!
                 self.contacterror()
         return
@@ -1279,6 +1283,8 @@ class TunapieFrame(wx.Frame):
         #self.FaveListCtrl.SetFocus()
         
     def OnMainListCtrlListItemRightClick(self, event):
+        if self.reloading==1:
+            return
         self.PopupMenu(self.maincontext)
 
     def OnMaincontextPlayMenu(self, event):
@@ -1294,6 +1300,8 @@ class TunapieFrame(wx.Frame):
         self.OnTunapieToolBarRemfaveTool(1)
         
     def OnFaveListCtrlListItemRightClick(self, event):
+        if self.reloading==1:
+            return
         self.PopupMenu(self.favecontext)
     
     def OnTunapieFrameKeyUp(self, event):
@@ -1416,6 +1424,7 @@ class TunapieFrame(wx.Frame):
             (self.home,self.rdir,self.shoutice,self.maxd,self.newsize)
         self.setfontsize()
         self.download()
+        self.OnTunapieToolBarRadioTool(1)
 
     def OnFilemenuRecordqueueMenu(self, event):
         if self.reloading==1:
@@ -1520,8 +1529,10 @@ class TunapieFrame(wx.Frame):
             dlg.Destroy()
 
     def OnGenreBoxListItemSelected(self, event):
-        if self.reloading==1:
+        if self.reloading==1 or self.startup==1:
             return
         self.parsefiles()
-        self.updatemain(event.GetLabel().lower())
+        try: self.updatemain(event.GetLabel().lower())
+        except AttributeError:
+            pass
         event.Skip()
