@@ -14,7 +14,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 #
-#Version 0.4.4 07/07/08
+#Version 0.4.6 23/10/08
 
 import urllib
 import getpass
@@ -81,7 +81,10 @@ def decode(file,radio,adult,fav=0):
             try: stationbitrate[0]
             except IndexError:
                 if fav==0:
-                    stationname=['No Streams Available!']
+                    if data.find("503 Service")>-1:
+                        stationname=['Server Returned 503 - Unavailable']
+                    else:
+                        stationname=['No Streams Available!']
                     stationurl=[' ']
                     stationgenre=['Nothing!']
                     stationplaying=['Nothing!']
@@ -154,8 +157,7 @@ def decodeice(file,radio):
     oldpos=0
     data=f.read()    
     while 1:
-        prename=data.find('a class="nav',pos)
-        name=data.find('<b>',prename)
+        name=data.find('<server_name>',pos)
         if(name==-1 or pos<oldpos):
             try: stationbitrate[0]
             except IndexError:
@@ -168,45 +170,40 @@ def decodeice(file,radio):
             return(stationurl,stationname,stationgenre,\
                           stationplaying,stationbitrate,stationlisteners)
         oldpos=pos
-        nameend=data.find('</b>',name)
-        title=data.find('title="',nameend)
-        titleend=data.find('"',title+7)
-        preurl=data.find('Now playing on',titleend)
-        url=data.find('href="',preurl)
-        urlend=data.find('"',url+6)
-        preplaying=data.find('font',urlend)
-        playing=data.find('>',preplaying)
-        playingend=data.find('</font>',playing+1)
-        pregenre=data.find('font',playingend+7)
-        genre=data.find('>',pregenre)
-        genreend=data.find('</font>',genre)
+        nameend=data.find('</serv',name)
+        url=data.find('<listen_url>',nameend)
+        urlend=data.find('</list',url)
+        servertype=data.find('<server_type>', urlend)
+        servertypeend=data.find('</serv', servertype)
+        bitrate=data.find('<bitrate>', servertypeend)
+        bitrateend=data.find('</bitr', bitrate)
+        genre=data.find('<genre>',bitrateend)
+        genreend=data.find('</genr',genre)
+        playing=data.find('<current_song>',genreend)
+        playingend=data.find('</curr',playing)
         if not(radio):
-            if (data[genre:genreend].lower().find('video')==-1 and data[genre:genreend].lower().find('tv')==-1):
-                pos=titleend+1
+            if (data[servertype:servertypeend].lower().find('video')==-1):
+                pos=playingend+6
                 continue
         else:
-            if data[genre:genreend].lower().find('video')>-1|data[genre:genreend].lower().find('tv')>-1:
-                pos=titleend+1
+            if data[servertype:servertypeend].lower().find('video')>-1:
+                pos=playingend+6
                 continue
-        bitrate=data.find('center>',genreend)
-        bitrateend=data.find('<',bitrate)
-        listeners="0"
-        pos=bitrateend+1
+        pos=playingend+6
         if pos<oldpos:
             continue
-        fixedname=fixunicode(data[name+3:nameend])
+        fixedname=fixunicode(data[name+13:nameend])
         stationname.append(fixedname)
-        if data[url+6:urlend].find('http://')==-1:
-            stationurl.append('http://dir.xiph.org/'+data[url+6:urlend])
+        if data[url+12:urlend].find('http://')==-1:
+            stationurl.append('http://dir.xiph.org/'+data[url+12:urlend])
         else:
-            stationurl.append(data[url+6:urlend])
-        fixedplaying=fixunicode(data[playing+1:playingend])
+            stationurl.append(data[url+12:urlend])
+        fixedplaying=fixunicode(data[playing+14:playingend])
         stationplaying.append(fixedplaying)
-        fixedgenre=fixunicode(data[genre+1:genreend])
+        fixedgenre=fixunicode(data[genre+7:genreend])
         stationgenre.append(fixedgenre)
-        stationlisteners.append(listeners)
-        bitrate=data[bitrate+7:bitrateend]
-        bitrate=bitrate[0:bitrate.find('kb')]
+        stationlisteners.append("0")
+        bitrate=data[bitrate+9:bitrateend]
         try: int(bitrate)
         except: bitrate="0"
         stationbitrate.append(bitrate)
@@ -215,10 +212,17 @@ def playselection(mediaplayer,pls,info=0):
         commands.getoutput("rm -rf /tmp/"+getpass.getuser()+"*_tunapie_temp.pls")
         tstamp=str(time.time())
         tempfile=open('/tmp/'+getpass.getuser()+tstamp+'_tunapie_temp.pls','w')
+        urldata=urllib.urlopen(pls)
+        notempfile=0
+        if (str(urldata.read(10)).find("playlist")==-1):
+            notempfile=1
+        urldata.close()
         playlist=urllib.urlopen(pls)
         if (info):
+            if notempfile:
+                return[]
             return playlist.readlines()
-        if mediaplayer.find('realplay')>-1:
+        if mediaplayer.find('realplay')>-1 or notempfile:
             os.system(mediaplayer+" "+pls+" &")
             return
         plist=playlist.readlines()
